@@ -29,16 +29,22 @@ impl PyTrainer {
     pub(crate) fn get_as_subtype(&self, py: Python<'_>) -> PyResult<PyObject> {
         let base = self.clone();
         Ok(match *self.trainer.as_ref().read().unwrap() {
-            TrainerWrapper::BpeTrainer(_) => Py::new(py, (PyBpeTrainer {}, base))?.into_py(py),
-            TrainerWrapper::WordPieceTrainer(_) => {
-                Py::new(py, (PyWordPieceTrainer {}, base))?.into_py(py)
-            }
-            TrainerWrapper::WordLevelTrainer(_) => {
-                Py::new(py, (PyWordLevelTrainer {}, base))?.into_py(py)
-            }
-            TrainerWrapper::UnigramTrainer(_) => {
-                Py::new(py, (PyUnigramTrainer {}, base))?.into_py(py)
-            }
+            TrainerWrapper::BpeTrainer(_) => Py::new(py, (PyBpeTrainer {}, base))?
+                .into_pyobject(py)?
+                .into_any()
+                .into(),
+            TrainerWrapper::WordPieceTrainer(_) => Py::new(py, (PyWordPieceTrainer {}, base))?
+                .into_pyobject(py)?
+                .into_any()
+                .into(),
+            TrainerWrapper::WordLevelTrainer(_) => Py::new(py, (PyWordLevelTrainer {}, base))?
+                .into_pyobject(py)?
+                .into_any()
+                .into(),
+            TrainerWrapper::UnigramTrainer(_) => Py::new(py, (PyUnigramTrainer {}, base))?
+                .into_pyobject(py)?
+                .into_any()
+                .into(),
         })
     }
 }
@@ -47,11 +53,10 @@ impl PyTrainer {
     fn __getstate__(&self, py: Python) -> PyResult<PyObject> {
         let data = serde_json::to_string(&self.trainer).map_err(|e| {
             exceptions::PyException::new_err(format!(
-                "Error while attempting to pickle PyTrainer: {}",
-                e
+                "Error while attempting to pickle PyTrainer: {e}"
             ))
         })?;
-        Ok(PyBytes::new_bound(py, data.as_bytes()).to_object(py))
+        Ok(PyBytes::new(py, data.as_bytes()).into())
     }
 
     fn __setstate__(&mut self, py: Python, state: PyObject) -> PyResult<()> {
@@ -59,8 +64,7 @@ impl PyTrainer {
             Ok(s) => {
                 let unpickled = serde_json::from_slice(s).map_err(|e| {
                     exceptions::PyException::new_err(format!(
-                        "Error while attempting to unpickle PyTrainer: {}",
-                        e
+                        "Error while attempting to unpickle PyTrainer: {e}"
                     ))
                 })?;
                 self.trainer = unpickled;
@@ -354,7 +358,7 @@ impl PyBpeTrainer {
                         builder = builder.continuing_subword_prefix(val.extract()?)
                     }
                     "end_of_word_suffix" => builder = builder.end_of_word_suffix(val.extract()?),
-                    _ => println!("Ignored unknown kwargs option {}", key),
+                    _ => println!("Ignored unknown kwargs option {key}"),
                 };
             }
         }
@@ -560,7 +564,7 @@ impl PyWordPieceTrainer {
                         builder = builder.continuing_subword_prefix(val.extract()?)
                     }
                     "end_of_word_suffix" => builder = builder.end_of_word_suffix(val.extract()?),
-                    _ => println!("Ignored unknown kwargs option {}", key),
+                    _ => println!("Ignored unknown kwargs option {key}"),
                 };
             }
         }
@@ -693,7 +697,7 @@ impl PyWordLevelTrainer {
                                 .collect::<PyResult<Vec<_>>>()?,
                         );
                     }
-                    _ => println!("Ignored unknown kwargs option {}", key),
+                    _ => println!("Ignored unknown kwargs option {key}"),
                 }
             }
         }
@@ -866,7 +870,7 @@ impl PyUnigramTrainer {
                             .collect::<PyResult<Vec<_>>>()?,
                     ),
                     _ => {
-                        println!("Ignored unknown kwargs option {}", key);
+                        println!("Ignored unknown kwargs option {key}");
                         &mut builder
                     }
                 };
@@ -875,7 +879,7 @@ impl PyUnigramTrainer {
 
         let trainer: tokenizers::models::unigram::UnigramTrainer =
             builder.build().map_err(|e| {
-                exceptions::PyException::new_err(format!("Cannot build UnigramTrainer: {}", e))
+                exceptions::PyException::new_err(format!("Cannot build UnigramTrainer: {e}"))
             })?;
         Ok((PyUnigramTrainer {}, trainer.into()))
     }
